"""
Copyright 2012 Dian-Je Tsai and Wantoto Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


def str2bool(raw_value):
    if raw_value.isdigit():
        return raw_value != '0'
    elif raw_value.lower() in ('false', 'no', 'f', 'n'):
        return False
    elif raw_value.lower() in ('true', 'yes', 't', 'y'):
        return True
    else:
        raise ValueError('%s is not a valid boolean string.')
